@@ -16,8 +16,8 @@ class SessionIPSQuerySet(AuditQuerySet):
 
 class SessionIPSManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
         }
