@@ -13,8 +13,8 @@ logger = logging.getLogger(__name__)
 
 
 class Messages_theme_admin_view_Manager(CommonTreeGridManager):
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             "id": record.id,
             "code": record.code,
